@@ -576,9 +576,9 @@ class Completer(Configurable):
         """
     ).tag(config=True)
 
-    use_jedi = Bool(default_value=False,
+    use_jedi = Bool(default_value=JEDI_INSTALLED,
                     help="Experimental: Use Jedi to generate autocompletions. "
-                    "Off by default.").tag(config=True)
+                    "Default to True if jedi is installed.").tag(config=True)
 
     jedi_compute_type_timeout = Int(default_value=400,
         help="""Experimental: restrict time (in milliseconds) during which Jedi can compute types.
@@ -1134,10 +1134,15 @@ class IPCompleter(Completer):
                 self.dict_key_matches,
             ]
 
-    def all_completions(self, text):
+    def all_completions(self, text) -> List[str]:
         """
-        Wrapper around the complete method for the benefit of emacs.
+        Wrapper around the completions method for the benefit of emacs.
         """
+        prefix = text[:text.rfind(".") + 1]
+        with provisionalcompleter():
+            return list(map(lambda c: prefix + c.text,
+                   self.completions(text, len(text))))
+
         return self.complete(text)[1]
 
     def _clean_glob(self, text):
